<!-- Thank you for using the Retarus Python SDK

--->

## Error description
<!-- Tell us what happened -->

## Steps to reproduce

<!-- Please include full steps to reproduce the issue so that we can do the same. -->

1. Execute the code sample <!-- (see "Code sample" section below) -->
2. ... <!-- describe steps to demonstrate bug -->
3. ... <!-- for example "Input a value, see how it crashes" -->

**Expected results:** <!-- what did you want to see? -->

**Actual results:** <!-- what did you see? -->

<details>
<summary>Code sample</summary>
